nxp-pac

Crates

git

Versions

lpc55s16

Flavors

FlashRemapSize

Struct FlashRemapSize 

#[repr(transparent)]
pub struct FlashRemapSize(pub u32);
This 32-bit register contains the size of the image to remap, in bytes. The 12 LSBs are ignored, so the size granularity is 4KB.

Tuple Fields

0: u32

Implementations

Source

impl FlashRemapSize

pub const fn field(&self) -> u32

no description available

pub const fn set_field(&mut self, val: u32)

no description available