#[repr(transparent)]pub struct FlashRemapSize(pub u32);Expand description
This 32-bit register contains the size of the image to remap, in bytes. The 12 LSBs are ignored, so the size granularity is 4KB.
Tuple Fields
0: u32Implementations